@@ -1,10 +1,12 @@
 use std::fmt;
 use std::fmt::Write;
 
+use crate::errors::LocItem;
 use pyo3::exceptions::PyValueError;
 use pyo3::prelude::*;
 use pyo3::types::PyDict;
 
+use crate::build_tools::py_error_type;
 use crate::input::repr_string;
 
 use super::kinds::ErrorKind;
@@ -21,16 +23,20 @@ pub struct ValidationError {
 }
 
 impl ValidationError {
-    pub fn from_val_error(py: Python, title: PyObject, error: ValError) -> PyErr {
+    pub fn from_val_error(py: Python, title: PyObject, error: ValError, outer_location: Option<LocItem>) -> PyErr {
         match error {
             ValError::LineErrors(raw_errors) => {
-                let line_errors: Vec<PyLineError> = raw_errors.into_iter().map(|e| e.into_py(py)).collect();
+                let line_errors: Vec<PyLineError> = match outer_location {
+                    Some(outer_location) => raw_errors
+                        .into_iter()
+                        .map(|e| e.with_outer_location(outer_location.clone()).into_py(py))
+                        .collect(),
+                    None => raw_errors.into_iter().map(|e| e.into_py(py)).collect(),
+                };
                 PyErr::new::<ValidationError, _>((line_errors, title))
             }
             ValError::InternalErr(err) => err,
-            ValError::Omit => {
-                PyValueError::new_err("Uncaught Omit error, please check your usage of `default` validators.")
-            }
+            ValError::Omit => Self::omit_error(),
         }
     }
 
@@ -41,6 +47,10 @@ impl ValidationError {
         let line_errors = pretty_py_line_errors(py, self.line_errors.iter());
         format!("{} validation error{} for {}\n{}", count, plural, title, line_errors)
     }
+
+    pub fn omit_error() -> PyErr {
+        py_error_type!("Uncaught Omit error, please check your usage of `default` validators.")
+    }
 }
 
 // used to convert a validation error back to ValError for wrap functions
@@ -70,11 +80,11 @@ impl ValidationError {
         self.line_errors.len()
     }
 
-    fn errors(&self, py: Python) -> PyResult<PyObject> {
+    fn errors(&self, py: Python, include_context: Option<bool>) -> PyResult<PyObject> {
         Ok(self
             .line_errors
             .iter()
-            .map(|e| e.as_dict(py))
+            .map(|e| e.as_dict(py, include_context))
             .collect::<PyResult<Vec<PyObject>>>()?
             .into_py(py))
     }
@@ -143,14 +153,16 @@ impl<'a> IntoPy<ValLineError<'a>> for PyLineError {
 }
 
 impl PyLineError {
-    pub fn as_dict(&self, py: Python) -> PyResult<PyObject> {
+    pub fn as_dict(&self, py: Python, include_context: Option<bool>) -> PyResult<PyObject> {
         let dict = PyDict::new(py);
         dict.set_item("kind", self.kind.kind())?;
         dict.set_item("loc", self.location.to_object(py))?;
         dict.set_item("message", self.kind.render_message(py)?)?;
         dict.set_item("input_value", &self.input_value)?;
-        if let Some(context) = self.kind.py_dict(py)? {
-            dict.set_item("context", context)?;
+        if include_context.unwrap_or(true) {
+            if let Some(context) = self.kind.py_dict(py)? {
+                dict.set_item("context", context)?;
+            }
         }
         Ok(dict.into_py(py))
     }
