@@ -1,5 +1,4 @@
 use pyo3::prelude::*;
-use pyo3::types::PyType;
 
 use crate::errors::{ErrorKind, InputValue, LocItem, ValError, ValResult};
 
@@ -38,7 +37,7 @@ impl<'a> Input<'a> for JsonInput {
         matches!(self, JsonInput::Null)
     }
 
-    fn is_instance(&self, _class: &PyType, json_mask: u8) -> PyResult<bool> {
+    fn input_is_instance(&self, _class: &PyAny, json_mask: u8) -> PyResult<bool> {
         if json_mask == 0 {
             Ok(false)
         } else {
@@ -294,8 +293,8 @@ impl<'a> Input<'a> for JsonInput {
     fn lax_timedelta(&self) -> ValResult<EitherTimedelta> {
         match self {
             JsonInput::String(v) => bytes_as_timedelta(self, v.as_bytes()),
-            JsonInput::Int(v) => Ok(int_as_duration(*v).into()),
-            JsonInput::Float(v) => Ok(float_as_duration(*v).into()),
+            JsonInput::Int(v) => Ok(int_as_duration(self, *v)?.into()),
+            JsonInput::Float(v) => Ok(float_as_duration(self, *v)?.into()),
             _ => Err(ValError::new(ErrorKind::TimeDeltaType, self)),
         }
     }
@@ -320,7 +319,7 @@ impl<'a> Input<'a> for String {
         false
     }
 
-    fn is_instance(&self, _class: &PyType, json_mask: u8) -> PyResult<bool> {
+    fn input_is_instance(&self, _class: &PyAny, json_mask: u8) -> PyResult<bool> {
         if json_mask == 0 {
             Ok(false)
         } else {
