@@ -2,7 +2,7 @@ use pyo3::intern;
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PySet, PyType};
 
-use crate::build_tools::SchemaDict;
+use crate::build_tools::{py_err, SchemaDict};
 use crate::errors::{ErrorKind, ValError, ValResult};
 use crate::input::{Input, JsonType};
 use crate::recursion_guard::RecursionGuard;
@@ -12,7 +12,7 @@ use super::{BuildContext, BuildValidator, CombinedValidator, Extra, Validator};
 
 #[derive(Debug, Clone)]
 pub struct IsInstanceValidator {
-    class: Py<PyType>,
+    class: PyObject,
     json_types: u8,
     json_function: Option<PyObject>,
     class_repr: String,
@@ -28,8 +28,23 @@ impl BuildValidator for IsInstanceValidator {
         _build_context: &mut BuildContext,
     ) -> PyResult<CombinedValidator> {
         let py = schema.py();
-        let class: &PyType = schema.get_as_req(intern!(py, "cls"))?;
-        let class_repr = class.name()?.to_string();
+        let cls_key = intern!(py, "cls");
+        let class: &PyAny = schema.get_as_req(cls_key)?;
+
+        // test that class works with isinstance to avoid errors at call time, reuse cls_key since it doesn't
+        // matter what object is being checked
+        let test_value: &PyAny = cls_key.as_ref();
+        if test_value.input_is_instance(class, 0).is_err() {
+            return py_err!("'cls' must be valid as the first argument to 'isinstance'");
+        }
+
+        let class_repr = match schema.get_as(intern!(py, "cls_repr"))? {
+            Some(s) => s,
+            None => match class.extract::<&PyType>() {
+                Ok(t) => t.name()?.to_string(),
+                Err(_) => class.repr()?.extract()?,
+            },
+        };
         let name = format!("{}[{}]", Self::EXPECTED_TYPE, class_repr);
         let json_types = match schema.get_as::<&PySet>(intern!(py, "json_types"))? {
             Some(s) => JsonType::combine(s)?,
@@ -55,7 +70,7 @@ impl Validator for IsInstanceValidator {
         _slots: &'data [CombinedValidator],
         _recursion_guard: &'s mut RecursionGuard,
     ) -> ValResult<'data, PyObject> {
-        match input.is_instance(self.class.as_ref(py), self.json_types)? {
+        match input.input_is_instance(self.class.as_ref(py), self.json_types)? {
             true => {
                 if input.get_type().is_json() {
                     if let Some(ref json_function) = self.json_function {
