@@ -52,16 +52,16 @@ def test_pydantic_value_error_usage():
 
 
 def test_pydantic_value_error_invalid_dict():
-    def f(input_value, **kwargs):
+    def my_function(input_value, **kwargs):
         raise PydanticCustomError('my_error', 'this is a custom error {foo}', {(): 'foobar'})
 
-    v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': f})
+    v = SchemaValidator({'type': 'function', 'mode': 'plain', 'function': my_function})
 
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python(42)
 
     assert str(exc_info.value) == (
-        '1 validation error for function-plain\n'
+        '1 validation error for function-plain[my_function()]\n'
         "  (error rendering message: TypeError: 'tuple' object cannot be converted to 'PyString') "
         '[kind=my_error, input_value=42, input_type=int]'
     )
@@ -239,6 +239,7 @@ def test_pydantic_error_kind_raise_ctx():
         ('time_delta_parsing', 'Input should be a valid timedelta, foobar', {'error': 'foobar'}),
         ('frozen_set_type', 'Input should be a valid frozenset', None),
         ('is_instance_of', 'Input should be an instance of Foo', {'class': 'Foo'}),
+        ('is_subclass_of', 'Input should be a subclass of Foo', {'class': 'Foo'}),
         ('callable_type', 'Input should be callable', None),
         (
             'union_tag_invalid',
