@@ -1,5 +1,6 @@
 import platform
 import re
+from collections import deque
 from typing import Any, Dict, Type
 
 import pytest
@@ -7,7 +8,7 @@ from dirty_equals import IsNonNegative
 
 from pydantic_core import SchemaValidator, ValidationError
 
-from ..conftest import Err, PyAndJson
+from ..conftest import Err, PyAndJson, infinite_generator
 
 
 @pytest.mark.parametrize(
@@ -84,10 +85,25 @@ def test_tuple_strict_fails_without_tuple(wrong_coll_type: Type[Any], mode, item
     [
         ({}, (1, 2, 3, 4), (1, 2, 3, 4)),
         ({'min_length': 3}, (1, 2, 3, 4), (1, 2, 3, 4)),
-        ({'min_length': 3}, (1, 2), Err('Input should have at least 3 items, got 2 items [kind=too_short,')),
+        ({'min_length': 3}, (1, 2), Err('Tuple should have at least 3 items after validation, not 2 [kind=too_short,')),
         ({'max_length': 4}, (1, 2, 3, 4), (1, 2, 3, 4)),
-        ({'max_length': 3}, (1, 2, 3, 4), Err('Input should have at most 3 items, got 4 items [kind=too_long,')),
+        (
+            {'max_length': 3},
+            (1, 2, 3, 4),
+            Err('Tuple should have at most 3 items after validation, not 4 [kind=too_long,'),
+        ),
+        (
+            {'max_length': 3},
+            [1, 2, 3, 4],
+            Err('Tuple should have at most 3 items after validation, not 4 [kind=too_long,'),
+        ),
+        (
+            {'max_length': 3},
+            infinite_generator(),
+            Err('Tuple should have at most 3 items after validation, not 4 [kind=too_long,'),
+        ),
     ],
+    ids=repr,
 )
 def test_tuple_var_len_kwargs(kwargs: Dict[str, Any], input_value, expected):
     v = SchemaValidator({'type': 'tuple', 'mode': 'variable', **kwargs})
@@ -106,6 +122,7 @@ def test_tuple_var_len_kwargs(kwargs: Dict[str, Any], input_value, expected):
     [
         ((1, 2, '3'), (1, 2, 3)),
         ([1, 2, '3'], (1, 2, 3)),
+        (deque((1, 2, '3')), (1, 2, 3)),
         pytest.param(
             {1: 10, 2: 20, '3': '30'}.keys(),
             (1, 2, 3),
@@ -124,6 +141,7 @@ def test_tuple_var_len_kwargs(kwargs: Dict[str, Any], input_value, expected):
         ({1, 2, '3'}, Err('Input should be a valid tuple [kind=tuple_type,')),
         (frozenset([1, 2, '3']), Err('Input should be a valid tuple [kind=tuple_type,')),
     ],
+    ids=repr,
 )
 def test_tuple_validate(input_value, expected, mode, items):
     v = SchemaValidator({'type': 'tuple', 'mode': mode, 'items_schema': items})
@@ -225,13 +243,14 @@ def test_extra_arguments(py_and_json: PyAndJson):
     assert v.validate_test([1, 2]) == (1, 2)
     with pytest.raises(ValidationError) as exc_info:
         v.validate_test([1, 2, 3, 4])
+    # insert_assert(exc_info.value.errors())
     assert exc_info.value.errors() == [
         {
             'kind': 'too_long',
             'loc': [],
-            'message': 'Input should have at most 2 items, got 4 items',
+            'message': 'Tuple should have at most 2 items after validation, not 4',
             'input_value': [1, 2, 3, 4],
-            'context': {'max_length': 2, 'input_length': 4},
+            'context': {'field_type': 'Tuple', 'max_length': 2, 'actual_length': 4},
         }
     ]
 
@@ -373,7 +392,24 @@ def test_tuple_fix_error():
     assert exc_info.value.errors() == [{'kind': 'missing', 'loc': [1], 'message': 'Field required', 'input_value': [1]}]
 
 
-def test_tuple_fix_extra():
+@pytest.mark.parametrize(
+    'input_value,expected',
+    [
+        ([1, 'a'], (1, 'a')),
+        ((1, 'a'), (1, 'a')),
+        ((1, 'a', 'b'), (1, 'a', 'b')),
+        ([1, 'a', 'b', 'c', 'd'], (1, 'a', 'b', 'c', 'd')),
+        (deque([1, 'a', 'b', 'c', 'd']), (1, 'a', 'b', 'c', 'd')),
+        (
+            [1],
+            Err(
+                'kind=missing',
+                errors=[{'kind': 'missing', 'loc': [1], 'message': 'Field required', 'input_value': [1]}],
+            ),
+        ),
+    ],
+)
+def test_tuple_fix_extra(input_value, expected, cache):
     v = SchemaValidator(
         {
             'type': 'tuple',
@@ -382,13 +418,13 @@ def test_tuple_fix_extra():
             'extra_schema': {'type': 'str'},
         }
     )
-    assert v.validate_python([1, 'a']) == (1, 'a')
-    assert v.validate_python((1, 'a')) == (1, 'a')
-    assert v.validate_python((1, 'a', 'b')) == (1, 'a', 'b')
-    assert v.validate_python([1, 'a', 'b', 'c', 'd']) == (1, 'a', 'b', 'c', 'd')
-    with pytest.raises(ValidationError) as exc_info:
-        v.validate_python([1])
-    assert exc_info.value.errors() == [{'kind': 'missing', 'loc': [1], 'message': 'Field required', 'input_value': [1]}]
+
+    if isinstance(expected, Err):
+        with pytest.raises(ValidationError, match=re.escape(expected.message)) as exc_info:
+            v.validate_python(input_value)
+        assert exc_info.value.errors() == expected.errors
+    else:
+        assert v.validate_python(input_value) == expected
 
 
 def test_tuple_fix_extra_any():
@@ -415,7 +451,8 @@ def test_generator_error():
     v = SchemaValidator({'type': 'tuple', 'items_schema': {'type': 'int'}})
     assert v.validate_python(gen(False)) == (1, 2, 3)
 
-    with pytest.raises(ValidationError, match=r'Error iterating over object \[kind=iteration_error,'):
+    msg = r'Error iterating over object, error: RuntimeError: error \[kind=iteration_error,'
+    with pytest.raises(ValidationError, match=msg):
         v.validate_python(gen(True))
 
 
@@ -443,3 +480,26 @@ def test_frozenset_from_dict_items(input_value, items_schema, expected):
     output = v.validate_python(input_value)
     assert isinstance(output, tuple)
     assert output == expected
+
+
+@pytest.mark.parametrize(
+    'input_value,expected',
+    [
+        ([1, 2, 3, 4], (1, 2, 3, 4)),
+        ([1, 2, 3, 4, 5], Err('Tuple should have at most 4 items after validation, not 5 [kind=too_long,')),
+        ([1, 2, 3, 'x', 4], (1, 2, 3, 4)),
+    ],
+)
+def test_length_constraints_omit(input_value, expected):
+    v = SchemaValidator(
+        {
+            'type': 'tuple',
+            'items_schema': {'type': 'default', 'schema': {'type': 'int'}, 'on_error': 'omit'},
+            'max_length': 4,
+        }
+    )
+    if isinstance(expected, Err):
+        with pytest.raises(ValidationError, match=re.escape(expected.message)):
+            v.validate_python(input_value)
+    else:
+        assert v.validate_python(input_value) == expected
